@@ -17,6 +17,12 @@ class FloatShield(BaseShield):
 
     actuator_bits = 12
 
+    class PlotInfo:
+        sensor_unit = "mm"
+        sensor_type = "Distance"
+        sensor_min = 0
+        sensor_max = 320
+
     def calibrate_sensor_reading(self, sensor: int) -> int:
         """Calibrate sensor reading. 0 is taken as the ball being at the bottome of the tube.
 
